==> Velvet-0.0.1.tgz: package/velvet.js <==
var http = require('http');
var path = require('path');
var fs = require('fs');
var nonogo = require('/Users/juliojimenez/Desktop/Julio\ Jimenez/Web/nonogo/nonogo.js');

var velvet = exports;

velvet.checkUser = function(username, password, callback) {
	nonogo.open('velvet', '1', 'RC4', 'asdf', function(error, v) {
		try
		{
			if (error) throw error;
			console.log(v);
			for (var i = 0; i < v.users.length; i++)
			{
				if (v.users[i].user == username && v.users[i].password == password)
				{
					process.nextTick(function() {
						callback(null, true);
					});
				}
				else
				{
					process.nextTick(function() {
						callback(null, false);
					});			
				}
			}
		}
		catch(err)
		{
			process.nextTick(function() {
                        	callback(err, true);
                        });
		}
	});
};

velvet.checkSession = function(username, request, callback) {
	try
        {
		var cookieRaw = request.headers.cookie;
		
		if (cookieRaw != undefined)
		{
			var cookieParts = cookieRaw.split('=');
						
			nonogo.open('velvet', '1', 'RC4', 'asdf', function(error, v) {
				try
				{
					if (error) throw error;

					for (var i = 0; i < v.users.length; i++)
					{
						if (v.users[i].user == username && v.users[i].session == cookieParts[1])
						{
							process.nextTick(function() {
								callback(null, true);
							});
						}							
						else
						{
							process.nextTick(function() {
                                                                callback(null, false);
                                                        });  	
						}
					}
				}
				catch(err)
				{
					process.nextTick(function() {
						callback(err, false);
					});
				}
			});
		}
		else
		{
			process.nextTick(function() {
				callback(null, undefined);
			});
		}
	}
	catch(err)
	{
		process.nextTick(function() {
			callback(err, false);
		});
	}
};

velvet.createSession = function(username, maxAge, response, callback) {
	try
	{
		var sid = 0x80000000000 * Math.random() + Date.parse(Date());
		var value = "sid=" + sid + ";Max-Age=" + maxAge;

		response.setHeader('Set-Cookie', value);
		
		nonogo.open('velvet', '1', 'RC4', 'asdf', function(error, v) {
			try
			{
				if (error) throw error;

				for (var i = 0; i < v.users.length; i++)
				{
					if (v.users[i].user == username)
					{
						nonogo.addField("users", i, "session", sid, function(error, v) {
							nonogo.commit(function(error) {
								if (error) throw error;
								process.nextTick(function() {
									callback(null);
								});
							});
						});
					}
				}
			}
			catch(err)
			{
				process.nextTick(function() {
					callback(err);
				});
			}
		});						
	}
	catch(err)
	{
		process.nextTick(function() {
                        callback(err);
                });
	}
};

velvet.destroySession = function(username, callback) {
	nonogo.open('velvet', '1', 'RC4', 'asdf', function(error, v) {
		try
		{
			if (error) throw error;

			for (var i = 0; i < v.users.length; i++)
			{
				if (v.users[i].user == username)
				{
					nonogo.deleteField("users", i, "session", function(error, v1) {
						if (error) throw error;

						nonogo.commit(function(error) {
							username = undefined;	
							password = undefined;

							process.nextTick(function() {
								callback(undefined);
							});	
						});
					});
				}
			}
		}
		catch(err)
		{
			process.nextTick(function() {
				callback(error);
			});
		}
	});
};

function getHandler(filePath, response) {
        var extname = path.extname(filePath);
        var contentType = 'text/html';
        switch (extname) 
        {
                case '.js':
                        contentType = 'text/javascript';
                        break;
                case '.css':
                        contentType = 'text/css';
                        break;
        }
        path.exists(filePath, function(exists) {
                if (exists) 
                {
                        fs.readFile(filePath, function(error, content) {
                                if (error) 
                                {
                                        response.writeHead(500);
                                        response.end();
                                }
                                else 
                                {
                                        response.writeHead(200, { 'Content-Type': contentType });
                                        response.end(content, 'utf-8');
                                }
                        });
                }
                else 
                {
                        response.writeHead(404);
                        response.end("You're looking for a file that does not exist! :-(");
                }
        });
}

==> Velvet-0.0.3.tgz: package/velvet.js <==
var http = require('http');
var path = require('path');
var fs = require('fs');
var nonogo = require('nonogo');

var velvet = exports;

velvet.checkUser = function(username, password, callback) {
	nonogo.open('velvet', function(error, v) {
		try
		{
			if (error) throw error;
			console.log(v);
			for (var i = 0; i < v.users.length; i++)
			{
				if (v.users[i].user == username && v.users[i].password == password)
				{
					process.nextTick(function() {
						callback(null, true);
					});
				}
				else
				{
					process.nextTick(function() {
						callback(null, false);
					});			
				}
			}
		}
		catch(err)
		{
			process.nextTick(function() {
                        	callback(err, true);
                        });
		}
	});
};

velvet.checkSession = function(username, request, callback) {
	try
        {
		var cookieRaw = request.headers.cookie;
		
		if (cookieRaw != undefined)
		{
			var cookieParts = cookieRaw.split('=');
						
			nonogo.open('velvet', function(error, v) {
				try
				{
					if (error) throw error;

					for (var i = 0; i < v.users.length; i++)
					{
						if (v.users[i].user == username && v.users[i].session == cookieParts[1])
						{
							process.nextTick(function() {
								callback(null, true);
							});
						}							
						else
						{
							process.nextTick(function() {
                                                                callback(null, false);
                                                        });  	
						}
					}
				}
				catch(err)
				{
					process.nextTick(function() {
						callback(err, false);
					});
				}
			});
		}
		else
		{
			process.nextTick(function() {
				callback(null, undefined);
			});
		}
	}
	catch(err)
	{
		process.nextTick(function() {
			callback(err, false);
		});
	}
};

velvet.createSession = function(username, maxAge, response, callback) {
	try
	{
		var sid = 0x80000000000 * Math.random() + Date.parse(Date());
		var value = "sid=" + sid + ";Max-Age=" + maxAge;

		response.setHeader('Set-Cookie', value);
		
		nonogo.open('velvet', function(error, v) {
			try
			{
				if (error) throw error;

				for (var i = 0; i < v.users.length; i++)
				{
					if (v.users[i].user == username)
					{
						nonogo.addField("users", i, "session", sid, function(error, v) {
							nonogo.commit(function(error) {
								if (error) throw error;
								process.nextTick(function() {
									callback(null);
								});
							});
						});
					}
				}
			}
			catch(err)
			{
				process.nextTick(function() {
					callback(err);
				});
			}
		});						
	}
	catch(err)
	{
		process.nextTick(function() {
                        callback(err);
                });
	}
};

velvet.destroySession = function(username, callback) {
	nonogo.open('velvet', function(error, v) {
		try
		{
			if (error) throw error;

			for (var i = 0; i < v.users.length; i++)
			{
				if (v.users[i].user == username)
				{
					nonogo.deleteField("users", i, "session", function(error, v1) {
						if (error) throw error;

						nonogo.commit(function(error) {
							username = undefined;	
							password = undefined;

							process.nextTick(function() {
								callback(undefined);
							});	
						});
					});
				}
			}
		}
		catch(err)
		{
			process.nextTick(function() {
				callback(error);
			});
		}
	});
};

function getHandler(filePath, response) {
        var extname = path.extname(filePath);
        var contentType = 'text/html';
        switch (extname) 
        {
                case '.js':
                        contentType = 'text/javascript';
                        break;
                case '.css':
                        contentType = 'text/css';
                        break;
        }
        path.exists(filePath, function(exists) {
                if (exists) 
                {
                        fs.readFile(filePath, function(error, content) {
                                if (error) 
                                {
                                        response.writeHead(500);
                                        response.end();
                                }
                                else 
                                {
                                        response.writeHead(200, { 'Content-Type': contentType });
                                        response.end(content, 'utf-8');
                                }
                        });
                }
                else 
                {
                        response.writeHead(404);
                        response.end("You're looking for a file that does not exist! :-(");
                }
        });
}
